c ParaDyn - Parallel DYNAMO - molecular dynamics with EAM potentials
c 
c Authored by Steve Plimpton
c   (505) 845-7873, sjplimp@cs.sandia.gov
c   Dept 9221, MS 1111, Sandia National Labs, Albuquerque, NM  87185-1111
c
c Based on the serial DYNAMO code authored by
c   Stephen Foiles (foiles@ca.sandia.gov), Sandia National Labs, Livermore, CA
c   Murray Daw (daw@hubcap.clemson.edu), Clemson University
c
c See the README file for more information
c
      
      subroutine start(iopflag)
#include "paradyn.h"
#include "mpif.h"
 900  format (1x,a,i8,a,e11.4)
 901  format (1x,a,g13.6,a,g13.6,a,g13.6)
 902  format (1x,a,g13.6,a,g13.6,a,g13.6)
 903  format (1x,a,3g13.6)
 904  format (1x,a,i5,a,i8,a,g13.6)
      
      if (node.eq.0) write (6,*) 'Setting up Run ...'

      if (natoms.eq.0) call error('No atoms defined')
      if (iopflag.eq.10.and.nvelocities.eq.0)
     $     call error('No velocities defined')
      
      c0 = 0.1875D0
      c1 = 0.697222222D0
      c2 = 1.0D0
      c3 = 0.61111111111D0
      c3 = 0.61111111111D0
      c4 = 0.16666666667D0
      c5 = 0.016666666667D0
      
      perlen(1) = perub(1) - perlb(1)
      perlen(2) = perub(2) - perlb(2)
      perlen(3) = perub(3) - perlb(3)
      
c initialize constant pressure stuff
      
      if (ibdtyp.eq.2) then
        bndmas(1) = 100.0D0
        bndmas(2) = 100.0D0
        bndmas(3) = 100.0D0
        trace = (dstress(1)+dstress(2)+dstress(3))/3.0D0
        dpress = dpress + trace
        dstress(1) = dstress(1) - trace
        dstress(2) = dstress(2) - trace
        dstress(3) = dstress(3) - trace
        bnddrg(1) = sqrt(7.5D0*perlen(1)/bndmas(1))
        bnddrg(2) = sqrt(7.5D0*perlen(2)/bndmas(2))
        bnddrg(3) = sqrt(7.5D0*perlen(3)/bndmas(3))
        dpress = dpress/1.602D6
        dstress(1) = dstress(1)/1.602D6
        dstress(2) = dstress(2)/1.602D6
        dstress(3) = dstress(3)/1.602D6
        dstress(1) = dstress(1)*perlen(2)*perlen(3)/perlen(1)
        dstress(2) = dstress(2)*perlen(1)*perlen(3)/perlen(2)
        dstress(3) = dstress(3)*perlen(1)*perlen(2)/perlen(3)
        if (iopflag.eq.9) then
          bndvel(1) = 0.0D0
          bndvel(2) = 0.0D0
          bndvel(3) = 0.0D0
        endif
      endif
      
c initialize statistics
      
      nave = 0
      avpe = 0.0D0
      avke = 0.0D0
      avpres = 0.0D0
      avtemp = 0.0D0
      avvol = 0.0D0
      do i = 1,6
        avstrs(i) = 0.0D0
      enddo
      
      nforce = -1
      nneigh = -1
      newlst = 1
      mxnsmall = 0
      mxnlarge = 0
      
      time_force = 0.0D0
      time_neigh = 0.0D0
      time_comm = 0.0D0
      avensmall = 0.0D0
      avenlarge = 0.0D0
      
c calculate initial state of system

      call scale
      call remap
      call unscale
      
c first call to userforce, comes before 1st call to force in thermo

      if (iuser.ne.0) call userforce(-1)

      call thermo(ekin1,epot1,etot1,temp,press,volint)

      eold = etot1
      demax = 0.0D0
      
      if (nmeth.eq.2.and.node.eq.0) then
        if (logflag.ne.0)
     $       write (1,*) 'Initial bins:',nbinx,nbiny,nbinz
        write (6,*) 'Initial bins:',nbinx,nbiny,nbinz
      endif

      if (logflag.ne.0.and.node.eq.0) then
        write (1,*)
        write (1,*) 'Initial Thermodynamics:'
        write (1,900) 'TimeStep =',nint(time_stamp/dt),
     $       '  Time =',time_stamp
        write (1,901) ' Total E =',etot1,' Pot E =',epot1,
     $       ' Kin E =',ekin1
        write (1,902) ' Temp =',temp,' Pressure =',press,
     $       ' Volume =',volint
        if (ibdtyp.eq.2) write (1,903) ' Box =',perlen(1),perlen(2),
     $       perlen(3)
        if (ntemps.gt.0) then
          do i = 0,ntemps
            write (1,904) ' Control',i,': Atoms =',tmpnum(i),
     $           ' Temp =',tmpnow(i)
          enddo
        endif
      endif
      
      if (node.eq.0) then
        write (6,*)
        write (6,*) 'Initial Thermodynamics:'
        write (6,900) 'TimeStep =',nint(time_stamp/dt),
     $       '  Time =',time_stamp
        write (6,901) ' Total E =',etot1,' Pot E =',epot1,
     $       ' Kin E =',ekin1
        write (6,902) ' Temp =',temp,' Pressure =',press,
     $       ' Volume =',volint
        if (ibdtyp.eq.2) write (6,903) ' Box =',perlen(1),perlen(2),
     $       perlen(3)
        if (ntemps.gt.0) then
          do i = 0,ntemps
            write (6,904) ' Control',i,': Atoms =',tmpnum(i),
     $           ' Temp =',tmpnow(i)
          enddo
        endif
      endif
      
c reinitialize timers after force call in thermo
      
      time_force = 0.0D0
      time_neigh = 0.0D0
      time_comm = 0.0D0
      time_io = 0.0D0
      avensmall = 0.0D0
      avenlarge = 0.0D0
      
c initialize temperature controls and parity
c for Langevin temperature control, set tmpseed via atom tag so
c   answers will be independent of atom ordering
      
      do i = 1,nlocal
        parity(1,i) = 0
        parity(2,i) = 0
        parity(3,i) = 0
        tmpseed(i) = langseed + tag(i)
      enddo
      langseed = langseed + natoms
      
      do i = 1,ntemps
        drag(i) = 0.0D0
      enddo

c diagnostic routine, call after 1st thermo, just before minimize/integrate
      
      if (idiag.ne.0) call diagnostic(0)

      return
      end
